<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Forum di SPIP (privati e pubblici)',
	'forum_slogan' => 'Gestione dei forum privati e pubblici di SPIP',
];
